summaryrefslogtreecommitdiff
path: root/includes/pear/Text/Wiki/Parse/Default/Horiz.php
diff options
context:
space:
mode:
Diffstat (limited to 'includes/pear/Text/Wiki/Parse/Default/Horiz.php')
-rwxr-xr-x[-rw-r--r--]includes/pear/Text/Wiki/Parse/Default/Horiz.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/includes/pear/Text/Wiki/Parse/Default/Horiz.php b/includes/pear/Text/Wiki/Parse/Default/Horiz.php
index a63cb5f..e8d06ec 100644..100755
--- a/includes/pear/Text/Wiki/Parse/Default/Horiz.php
+++ b/includes/pear/Text/Wiki/Parse/Default/Horiz.php
@@ -12,7 +12,7 @@
*
* @license LGPL
*
-* @version $Id: Horiz.php 180591 2005-02-23 17:38:29Z pmjones $
+* @version $Id$
*
*/
@@ -20,7 +20,7 @@
*
* Parses for horizontal ruling lines.
*
* This class implements a Text_Wiki_Parse to find source text marked to
* be a horizontal rule, as defined by four dashed on their own line.
*
* @category Text
@@ -31,7 +31,7 @@
*
*/
-class Text_Wiki_Parse_Horiz extends Text_Wiki_Parse {
+class Text_Wiki_Parse_Default_Horiz extends Text_Wiki_Parse {
/**
@@ -47,7 +47,7 @@ class Text_Wiki_Parse_Horiz extends Text_Wiki_Parse {
*
*/
- var $regex = '/^([-]{4,})$/m';
+ var $regex = "/^([-]{4,})$/m";
/**
@@ -67,4 +67,4 @@ class Text_Wiki_Parse_Horiz extends Text_Wiki_Parse {
return $this->wiki->addToken($this->rule);
}
}
-?> \ No newline at end of file
+?>
@@ -20,7 +20,7 @@
* Parses for horizontal ruling lines.
*
-* This class implements a Text_Wiki_Parse to find source text marked to
+* This class implements a Text_Wiki_Parse_Default to find source text marked to
* be a horizontal rule, as defined by four dashed on their own line.
*